summaryrefslogtreecommitdiffstats
path: root/bin/pax/buf_subs.c
diff options
context:
space:
mode:
Diffstat (limited to 'bin/pax/buf_subs.c')
-rw-r--r--bin/pax/buf_subs.c46
1 files changed, 23 insertions, 23 deletions
diff --git a/bin/pax/buf_subs.c b/bin/pax/buf_subs.c
index e04182a..6a579c5 100644
--- a/bin/pax/buf_subs.c
+++ b/bin/pax/buf_subs.c
@@ -34,7 +34,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id$
+ * $Id: buf_subs.c,v 1.7 1997/02/22 14:04:20 peter Exp $
*/
#ifndef lint
@@ -103,12 +103,12 @@ wr_start()
if (!wrblksz)
wrblksz = frmt->bsz;
if (wrblksz > MAXBLK) {
- warn(1, "Write block size of %d too large, maximium is: %d",
+ pax_warn(1, "Write block size of %d too large, maximium is: %d",
wrblksz, MAXBLK);
return(-1);
}
if (wrblksz % BLKMULT) {
- warn(1, "Write block size of %d is not a %d byte multiple",
+ pax_warn(1, "Write block size of %d is not a %d byte multiple",
wrblksz, BLKMULT);
return(-1);
}
@@ -148,12 +148,12 @@ rd_start()
buf = &(bufmem[BLKMULT]);
if ((act == APPND) && wrblksz) {
if (wrblksz > MAXBLK) {
- warn(1,"Write block size %d too large, maximium is: %d",
+ pax_warn(1,"Write block size %d too large, maximium is: %d",
wrblksz, MAXBLK);
return(-1);
}
if (wrblksz % BLKMULT) {
- warn(1, "Write block size %d is not a %d byte multiple",
+ pax_warn(1, "Write block size %d is not a %d byte multiple",
wrblksz, BLKMULT);
return(-1);
}
@@ -232,7 +232,7 @@ appnd_start(skcnt)
off_t cnt;
if (exit_val != 0) {
- warn(0, "Cannot append to an archive that may have flaws.");
+ pax_warn(0, "Cannot append to an archive that may have flaws.");
return(-1);
}
/*
@@ -309,7 +309,7 @@ appnd_start(skcnt)
return(0);
out:
- warn(1, "Unable to rewrite archive trailer, cannot append.");
+ pax_warn(1, "Unable to rewrite archive trailer, cannot append.");
return(-1);
}
@@ -341,7 +341,7 @@ rd_sync()
if (maxflt == 0)
return(-1);
if (act == APPND) {
- warn(1, "Unable to append when there are archive read errors.");
+ pax_warn(1, "Unable to append when there are archive read errors.");
return(-1);
}
@@ -375,7 +375,7 @@ rd_sync()
* can extract out of the archive.
*/
if ((maxflt > 0) && (++errcnt > maxflt))
- warn(0,"Archive read error limit (%d) reached",maxflt);
+ pax_warn(0,"Archive read error limit (%d) reached",maxflt);
else if (ar_rdsync() == 0)
continue;
if (ar_next() < 0)
@@ -654,7 +654,7 @@ wr_skip(skcnt)
* it is important that we always write EXACTLY the number of bytes that
* the format specific write routine told us to. The file can also get
* bigger, so reading to the end of file would create an improper archive,
* we just detect this case and warn the user. We never create a bad
* archive if we can avoid it. Of course trying to archive files that are
* active is asking for trouble. It we fail, we pass back how much we
* could NOT copy and let the caller deal with it.
@@ -700,13 +700,13 @@ wr_rdfile(arcn, ifd, left)
* or the file read failed.
*/
if (res < 0)
- syswarn(1, errno, "Read fault on %s", arcn->org_name);
+ sys_warn(1, errno, "Read fault on %s", arcn->org_name);
else if (size != 0L)
- warn(1, "File changed size during read %s", arcn->org_name);
+ pax_warn(1, "File changed size during read %s", arcn->org_name);
else if (fstat(ifd, &sb) < 0)
- syswarn(1, errno, "Failed stat on %s", arcn->org_name);
+ sys_warn(1, errno, "Failed stat on %s", arcn->org_name);
else if (arcn->sb.st_mtime != sb.st_mtime)
- warn(1, "File %s was modified during copy to archive",
+ pax_warn(1, "File %s was modified during copy to archive",
arcn->org_name);
*left = size;
return(0);
@@ -761,7 +761,7 @@ rd_wrfile(arcn, ofd, left)
if (sb.st_blksize > 0)
sz = (int)sb.st_blksize;
} else
- syswarn(0,errno,"Unable to obtain block size for file %s",fnm);
+ sys_warn(0,errno,"Unable to obtain block size for file %s",fnm);
rem = sz;
*left = 0L;
@@ -817,7 +817,7 @@ rd_wrfile(arcn, ofd, left)
* calculated crc to the crc stored in the archive
*/
if (docrc && (size == 0L) && (arcn->crc != crc))
- warn(1,"Actual crc does not match expected crc %s",arcn->name);
+ pax_warn(1,"Actual crc does not match expected crc %s",arcn->name);
return(0);
}
@@ -864,7 +864,7 @@ cp_file(arcn, fd1, fd2)
if (sb.st_blksize > 0)
sz = sb.st_blksize;
} else
- syswarn(0,errno,"Unable to obtain block size for file %s",fnm);
+ sys_warn(0,errno,"Unable to obtain block size for file %s",fnm);
rem = sz;
/*
@@ -886,15 +886,15 @@ cp_file(arcn, fd1, fd2)
* check to make sure the copy is valid.
*/
if (res < 0)
- syswarn(1, errno, "Failed write during copy of %s to %s",
+ sys_warn(1, errno, "Failed write during copy of %s to %s",
arcn->org_name, arcn->name);
else if (cpcnt != arcn->sb.st_size)
- warn(1, "File %s changed size during copy to %s",
+ pax_warn(1, "File %s changed size during copy to %s",
arcn->org_name, arcn->name);
else if (fstat(fd1, &sb) < 0)
- syswarn(1, errno, "Failed stat of %s", arcn->org_name);
+ sys_warn(1, errno, "Failed stat of %s", arcn->org_name);
else if (arcn->sb.st_mtime != sb.st_mtime)
- warn(1, "File %s was modified during copy to %s",
+ pax_warn(1, "File %s was modified during copy to %s",
arcn->org_name, arcn->name);
/*
@@ -987,7 +987,7 @@ buf_flush(bufcnt)
* at least one record. We always round limit UP to next blocksize.
*/
if ((wrlimit > 0) && (wrcnt > wrlimit)) {
- warn(0, "User specified archive volume byte limit reached.");
+ pax_warn(0, "User specified archive volume byte limit reached.");
if (ar_next() < 0) {
wrcnt = 0;
exit_val = 1;
@@ -1043,7 +1043,7 @@ buf_flush(bufcnt)
/*
* Oh drat we got a partial write!
* if format doesnt care about alignment let it go,
* we warned the user in ar_write().... but this means
* the last record on this volume violates pax spec....
*/
totcnt += cnt;
@@ -654,7 +654,7 @@ wr_skip(skcnt)
* the format specific write routine told us to. The file can also get
* bigger, so reading to the end of file would create an improper archive,
- * we just detect this case and warn the user. We never create a bad
+ * we just detect this case and pax_warn the user. We never create a bad
* archive if we can avoid it. Of course trying to archive files that are
* active is asking for trouble. It we fail, we pass back how much we
@@ -1043,7 +1043,7 @@ buf_flush(bufcnt)
* Oh drat we got a partial write!
* if format doesnt care about alignment let it go,
- * we warned the user in ar_write().... but this means
+ * we pax_warned the user in ar_write().... but this means
* the last record on this volume violates pax spec....
*/
OpenPOWER on IntegriCloud